<?php

namespace Drupal\gnode_request\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Routing\Access\AccessInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\gnode_request\Plugin\Group\Relation\GroupNodeRequest;
use Drupal\group\Entity\GroupRelationshipInterface;
use Symfony\Component\Routing\Route;

/**
 * Checks access for group membership request approval / rejection pages.
 */
class PendingGroupNodeRequestAccessChecker implements AccessInterface {

  /**
   * Checks access.
   *
   * @param \Symfony\Component\Routing\Route $route
   *   The route to check against.
   * @param \Drupal\group\Entity\GroupRelationshipInterface $group_relationship
   *   The group relationship to be operated on from the route.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function access(Route $route, GroupRelationshipInterface $group_relationship) {
    // Check check enabled.
    $requirement = $route->getRequirement('_pending_group_node_request');
    if ($requirement !== 'TRUE') {
      return AccessResult::neutral();
    }
    if ($group_relationship->getPlugin()->getBaseId() != 'group_node_request') {
      return FALSE;
    }

    if ($group_relationship->get(GroupNodeRequest::STATUS_FIELD)->value == GroupNodeRequest::REQUEST_PENDING) {
        return AccessResult::allowed();
    }
    return AccessResult::forbidden();
  }

}
