<?php

namespace Drupal\gnode_request\Controller;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Session\AccountInterface;
use Drupal\gnode_request\GnodeRequestManager;
use Drupal\group\Entity\GroupInterface;
use Drupal\group\Entity\GroupRelationshipInterface;
use Drupal\node\NodeInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides group membership request route controllers.
 */
class GroupNodeRequestController extends ControllerBase {

  /**
   * Membership request manager.
   *
   * @var \Drupal\gnode_request\GnodeRequestManager
   */
  protected $gnodeRequestManager;

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Group Membership request controller constructor.
   *
   * @param \Drupal\gnode_request\GnodeRequestManager $gnode_request_manager
   *   Membership request manager.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager service.
   */
  public function __construct(GnodeRequestManager $gnode_request_manager, EntityTypeManagerInterface $entity_type_manager) {
    $this->gnodeRequestManager = $gnode_request_manager;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('gnode_request.gnode_request_manager'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * Provides the form for approval a group membership.
   *
   * @param \Drupal\group\Entity\GroupRelationshipInterface $group_relationship
   *   The group relationship.
   *
   * @return array
   *   A group approval membership form.
   */
  public function approveMembership(GroupRelationshipInterface $group_relationship) {
    return $this->entityFormBuilder()->getForm($group_relationship, 'group-node-approve');
  }

  /**
   * Provides the form for rejection a group membership.
   *
   * @param \Drupal\group\Entity\GroupRelationshipInterface $group_relationship
   *   The group relationship.
   *
   * @return array
   *   A group rejection membership form.
   */
  public function rejectMembership(GroupRelationshipInterface $group_relationship) {
    return $this->entityFormBuilder()->getForm($group_relationship, 'group-node-reject');
  }

}
