<?php

declare(strict_types=1);

namespace Drupal\gnode_request\EventSubscriber;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\group\Entity\GroupRelationshipInterface;
use Drupal\state_machine\Event\WorkflowTransitionEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * @todo Add description for this subscriber.
 */
final class RequestTransitionSubscriber implements EventSubscriberInterface {

  /**
   * Constructs a RequestTransitionSubscriber object.
   */
  public function __construct(
    private readonly EntityTypeManagerInterface $entityTypeManager,
  ) {}

  /**
   * Accept node request: Create a group node relationship.
   */
  public function onAccept(WorkflowTransitionEvent $event): void {
    $group_relationship = $event->getEntity();
    assert($group_relationship instanceof GroupRelationshipInterface);

    // Don't loop.
    // @see gnode_request_group_relationship_create().
    if (isset($group_relationship->gnode_create)) {
      return;
    }

    $node = $group_relationship->getEntity();
    $node->gnode_request_approval = TRUE;
    $group_relationship->getGroup()->addRelationship($node, 'group_node:' . $node->bundle(), ['gnode_request_approval' => TRUE]);
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      'group_node_request.approve.pre_transition' => ['onAccept'],
    ];
  }

}
