<?php

declare(strict_types=1);

namespace Drupal\gnode_request\Plugin\Action;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Action\ActionBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\gnode_request\GnodeRequestManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Base class for group membership actions.
 */
abstract class MembershipRequestActionBase extends ActionBase implements ContainerFactoryPluginInterface {

  /**
   * Membership request manager.
   *
   * @var \Drupal\gnode_request\GnodeRequestManager
   */
  protected GnodeRequestManager $gnodeRequestManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    GnodeRequestManager $gnode_request_manager
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->gnodeRequestManager = $gnode_request_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('gnode_request.gnode_request_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function access($entity, AccountInterface $account = NULL, $return_as_object = FALSE) {
    $access = $entity->getGroup()->hasPermission('administer group node requests', $account);
    $result = $access ? AccessResult::allowed() : AccessResult::forbidden();
    return $return_as_object ? $result : $result->isAllowed();
  }

}
