<?php

namespace Drupal\gnode_request\Plugin\Group\Relation;

use Drupal\Core\Form\FormStateInterface;
use Drupal\group\Plugin\Group\Relation\GroupRelationBase;

/**
 * Provides a group relation for nodes as group membership request.
 *
 * @GroupRelationType(
 *   id = "group_node_request",
 *   label = @Translation("Group node request"),
 *   description = @Translation("Adds node requests to a group."),
 *   entity_type_id = "node",
 *   entity_access = TRUE,
 *   pretty_path_key = "request",
 *   reference_label = @Translation("Title"),
 *   reference_description = @Translation("The name of the node you want to add to a group."),
 *   admin_permission = "administer group node requests",
 *   deriver = "Drupal\gnode_request\Plugin\Group\Relation\GroupNodeRequestDeriver"
 * )
 */
class GroupNodeRequest extends GroupRelationBase {

  /**
   * Transition id for approval.
   */
  const TRANSITION_APPROVE = 'approve';

  /**
   * Transition id for approval.
   */
  const TRANSITION_REJECT = 'reject';

  /**
   * Transition id for creation.
   */
  const TRANSITION_CREATE = 'create';

  /**
   * Status field.
   */
  const STATUS_FIELD = 'gnode_request_status';

  /**
   * Request created by default with new status.
   */
  const REQUEST_NEW = 'new';

  /**
   * Request created and waiting for administrator's response.
   */
  const REQUEST_PENDING = 'pending';

  /**
   * Request is approved by administrator.
   */
  const REQUEST_APPROVED = 'approved';

  /**
   * Request is rejected by administrator.
   */
  const REQUEST_REJECTED = 'rejected';

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    $config = parent::defaultConfiguration();
    $config['entity_cardinality'] = 1;
    $config['remove_group_node_request'] = FALSE;
    return $config;
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);

    $form['remove_group_node_request'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Remove a request, when node is added to the group.'),
      '#default_value' => $this->getConfiguration()['remove_group_node_request'] ?? TRUE,
    ];

    // Disable the entity cardinality field as the functionality of this module
    // relies on a cardinality of 1. We don't just hide it, though, to keep a UI
    // that's consistent with other group relations.
    $info = $this->t("This field has been disabled by the plugin to guarantee the functionality that's expected of it.");
    $form['entity_cardinality']['#disabled'] = TRUE;
    $form['entity_cardinality']['#description'] .= '<br /><em>' . $info . '</em>';

    return $form;
  }

}
