<?php

namespace Drupal\gnode_request\Plugin\views\field;

use Drupal\gnode_request\Plugin\Group\Relation\GroupNodeRequest;
use Drupal\views\Plugin\views\field\EntityLink;
use Drupal\views\ResultRow;

/**
 * Field handler to present an entity link.
 */
abstract class MembershipEntityLink extends EntityLink {

  /**
   * {@inheritdoc}
   */
  protected function renderLink(ResultRow $row) {
    $base_plugin_id = 'group_node_request';

    /** @var \Drupal\group\Entity\GroupRelationship $group_relationship */
    $group_relationship = $row->_entity;
    $plugin_id = $group_relationship->getPlugin()->getPluginId();
    $group = $group_relationship->getGroup();
    $link = NULL;

    // Check if plugin exists.
    if (!$group->getGroupType()->hasPlugin($plugin_id)) {
      return $link;
    }

    // Check if current group relationship is type of group_node_request.
    if ($group_relationship->getPlugin()->getBaseId() !== $base_plugin_id) {
      return $link;
    }

    $node = $group_relationship->getEntity();
    // Check if group already have the node as a member.
    $nodes = $group->getRelatedEntities(str_replace('_request', '', $group_relationship->getPluginId()));
    if (array_filter($nodes, function ($n) use ($node) {
      return $node->id() === $n->id();
    })) {
      $link = $this->t('Already in group');
    }
    elseif ($group_relationship->get(GroupNodeRequest::STATUS_FIELD)->value === GroupNodeRequest::REQUEST_PENDING && $group->hasPermission('administer group node requests', $this->currentUser)) {
      $this->options['alter']['query'] = $this->getDestinationArray();
      $link = parent::renderLink($row);
    }

    return $link;
  }

}
